package com.dayou.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.dayou.common.RestResponse;
import com.dayou.dto.AssetsStatisticalSelectDTO;
import com.dayou.service.IAssetsStatisticalStatementService;
import com.dayou.vo.AssetsEvaluateDepEfficiencyVO;
import com.dayou.vo.AssetsLedgerVO;
import com.dayou.vo.AssetsPerformanceDeductionDetailVO;
import com.dayou.vo.AssetsPerformanceDeductionVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

@RestController
@RequestMapping("assets/statisticalStatement")
@Slf4j
public class AssetsStatisticalStatementController extends BaseController{

    @Autowired
    private IAssetsStatisticalStatementService assetsStatisticalStatementService;

    /**
     * 获取资产台账
     * @param dto 查询dto
     * @return Page<AssetsLedgerVO>
     */
    @GetMapping("/getAssetsLedgerVO")
    public RestResponse<Page<AssetsLedgerVO>> getAssetsLedgerVO(AssetsStatisticalSelectDTO dto, Page page) {
        return RestResponse.data(assetsStatisticalStatementService.getAssetsLedgerVO(dto,page));
    }

    /**
     * 资产台账导出
     * @param dto 查询dto
     */
    @GetMapping("/getAssetsLedgerVO/export")
    public void assetsLedgerVOExport(AssetsStatisticalSelectDTO dto, HttpServletResponse response) throws IOException {
        List<AssetsLedgerVO> result = assetsStatisticalStatementService.assetsLedgerVOExport(dto);
        exportPlus(response,"资产台账列表",result, AssetsLedgerVO.class);
    }

    /**
     * 评估部绩效扣分查询
     * @param dto 查询dto
     * @return List<AssetsPerformanceDeductionVO>
     */
    @GetMapping("/department/getAssetsPerformanceDeductionVO")
    public RestResponse<List<AssetsPerformanceDeductionVO>> getAssetsPerformanceDeductionVO(AssetsStatisticalSelectDTO dto) {
        return RestResponse.data(assetsStatisticalStatementService.getAssetsPerformanceDeductionVO(dto));
    }

    /**
     * 评估部绩效扣分导出
     * @param dto 查询dto
     */
    @GetMapping("/department/getAssetsPerformanceDeductionVO/export")
    public void assetsPerformanceDeductionVOExport(AssetsStatisticalSelectDTO dto, HttpServletResponse response) throws IOException {
        List<AssetsPerformanceDeductionVO> result = assetsStatisticalStatementService.assetsPerformanceDeductionVOExport(dto);
        exportPlus(response, "资产评估部绩效扣分", result, AssetsPerformanceDeductionVO.class);
    }

    /**
     * 查询错误详情列表
     * @param page 分页
     * @param dto 查询dto
     * @return Page<AssetsPerformanceDeductionDetailVO>
     */
    @GetMapping("/department/getAssetsPerformanceDeductionDetail")
    public RestResponse<Page<AssetsPerformanceDeductionDetailVO>> getAssetsPerformanceDeductionDetail(Page page, AssetsStatisticalSelectDTO dto) {
        return RestResponse.data(assetsStatisticalStatementService.getAssetsPerformanceDeductionDetail(page, dto));
    }

    /**
     * 错误详情列表导出
     * @param dto 查询dto
     */
    @GetMapping("/department/getAssetsPerformanceDeductionDetail/export")
    public void assetsPerformanceDeductionDetailExport(AssetsStatisticalSelectDTO dto, HttpServletResponse response) throws IOException {
        List<AssetsPerformanceDeductionDetailVO> result = assetsStatisticalStatementService.assetsPerformanceDeductionDetailExport(dto);
        String fileName = "资产评估部绩效扣分详情_" + dto.getCheckLoop();
        if (dto.getMistakeType().equals("normal")){
            fileName += "_" + "一般错误";
        } else if (dto.getMistakeType().equals("hard")) {
            fileName += "_" + "较大错误";
        }else {
            fileName += "_" + "重大错误";
        }
        exportPlus(response, fileName, result, AssetsPerformanceDeductionDetailVO.class);
    }

    /**
     * 评估人员绩效扣分查询
     * @param dto 查询dto
     * @return List<AssetsPerformanceDeductionVO>
     */
    @GetMapping("/evaluator/getAssetsPerformanceDeductionVO")
    public RestResponse<List<AssetsPerformanceDeductionVO>> getAssetsPerformanceDeductionVOByEvaluator(AssetsStatisticalSelectDTO dto) {
        return RestResponse.data(assetsStatisticalStatementService.getAssetsPerformanceDeductionVOByEvaluator(dto));
    }

    /**
     * 评估人员绩效扣分导出
     * @param dto 查询dto
     */
    @GetMapping("/evaluator/getAssetsPerformanceDeductionVO/export")
    public void assetsPerformanceDeductionVOByEvaluatorExport(AssetsStatisticalSelectDTO dto, HttpServletResponse response) throws IOException {
        List<AssetsPerformanceDeductionVO> result = assetsStatisticalStatementService.assetsPerformanceDeductionVOByEvaluatorExport(dto);
        exportPlus(response, "评估人员绩效扣分", result, AssetsPerformanceDeductionVO.class);
    }

    /**
     * 评估部效率查询
     * @param dto 查询dto
     * @return List<AssetsEvaluateDepEfficiencyVO>
     */
    @GetMapping("/evaluate/dep/getEfficiencyVO")
    public RestResponse<List<AssetsEvaluateDepEfficiencyVO>> getAssetsEvaluateDepEfficiencyVO(AssetsStatisticalSelectDTO dto) {
        return RestResponse.data(assetsStatisticalStatementService.getAssetsEvaluateDepEfficiencyVO(dto));
    }

    /**
     * 评估部效率导出
     * @param dto 查询dto
     */
    @GetMapping("/evaluate/dep/getEfficiencyVO/export")
    public void getAssetsEvaluateDepEfficiencyVOExport(AssetsStatisticalSelectDTO dto, HttpServletResponse response) throws IOException {
        List<AssetsEvaluateDepEfficiencyVO> result = assetsStatisticalStatementService.getAssetsEvaluateDepEfficiencyVO(dto);
        exportPlus(response, "评估部效率值表", result, AssetsEvaluateDepEfficiencyVO.class);
    }

}
